<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="et">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN käivitatud</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN lülitatud välja</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock lülitatud käes</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock lülitatud välja</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Numbritõmb lülitatud käes</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Numbritõmb lülitatud välja</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Kaugtastik lülitatud käes</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Kaugtastik lülitatud välja</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Kaugtastik vahetatakse</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn vahetatakse</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Lentimood lülitatud käes</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Lentimood lülitatud välja</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Võrdselt energia</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Energiahoidja</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Kõrge tähtsuse</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Aken efektid lubatud</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Aken efektid kahjustatud</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Aken efektide lubamine ebaõnnestus</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Microphone on</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>